import java.awt
import java.awt.font
import java.awt.im.spi
import java.lang
import java.text
import java.util
import typing



class InputContext:
    def dispatchEvent(self, aWTEvent: java.awt.AWTEvent) -> None: ...
    def dispose(self) -> None: ...
    def endComposition(self) -> None: ...
    def getInputMethodControlObject(self) -> typing.Any: ...
    @staticmethod
    def getInstance() -> 'InputContext': ...
    def getLocale(self) -> java.util.Locale: ...
    def isCompositionEnabled(self) -> bool: ...
    def reconvert(self) -> None: ...
    def removeNotify(self, component: java.awt.Component) -> None: ...
    def selectInputMethod(self, locale: java.util.Locale) -> bool: ...
    def setCharacterSubsets(self, subsetArray: typing.List[java.lang.Character.Subset]) -> None: ...
    def setCompositionEnabled(self, boolean: bool) -> None: ...

class InputMethodHighlight:
    RAW_TEXT: typing.ClassVar[int] = ...
    CONVERTED_TEXT: typing.ClassVar[int] = ...
    UNSELECTED_RAW_TEXT_HIGHLIGHT: typing.ClassVar['InputMethodHighlight'] = ...
    SELECTED_RAW_TEXT_HIGHLIGHT: typing.ClassVar['InputMethodHighlight'] = ...
    UNSELECTED_CONVERTED_TEXT_HIGHLIGHT: typing.ClassVar['InputMethodHighlight'] = ...
    SELECTED_CONVERTED_TEXT_HIGHLIGHT: typing.ClassVar['InputMethodHighlight'] = ...
    @typing.overload
    def __init__(self, boolean: bool, int: int): ...
    @typing.overload
    def __init__(self, boolean: bool, int: int, int2: int): ...
    @typing.overload
    def __init__(self, boolean: bool, int: int, int2: int, map: typing.Union[java.util.Map[java.awt.font.TextAttribute, typing.Any], typing.Mapping[java.awt.font.TextAttribute, typing.Any]]): ...
    def getState(self) -> int: ...
    def getStyle(self) -> java.util.Map[java.awt.font.TextAttribute, typing.Any]: ...
    def getVariation(self) -> int: ...
    def isSelected(self) -> bool: ...

class InputMethodRequests:
    def cancelLatestCommittedText(self, attributeArray: typing.List[java.text.AttributedCharacterIterator.Attribute]) -> java.text.AttributedCharacterIterator: ...
    def getCommittedText(self, int: int, int2: int, attributeArray: typing.List[java.text.AttributedCharacterIterator.Attribute]) -> java.text.AttributedCharacterIterator: ...
    def getCommittedTextLength(self) -> int: ...
    def getInsertPositionOffset(self) -> int: ...
    def getLocationOffset(self, int: int, int2: int) -> java.awt.font.TextHitInfo: ...
    def getSelectedText(self, attributeArray: typing.List[java.text.AttributedCharacterIterator.Attribute]) -> java.text.AttributedCharacterIterator: ...
    def getTextLocation(self, textHitInfo: java.awt.font.TextHitInfo) -> java.awt.Rectangle: ...

class InputSubset(java.lang.Character.Subset):
    LATIN: typing.ClassVar['InputSubset'] = ...
    LATIN_DIGITS: typing.ClassVar['InputSubset'] = ...
    TRADITIONAL_HANZI: typing.ClassVar['InputSubset'] = ...
    SIMPLIFIED_HANZI: typing.ClassVar['InputSubset'] = ...
    KANJI: typing.ClassVar['InputSubset'] = ...
    HANJA: typing.ClassVar['InputSubset'] = ...
    HALFWIDTH_KATAKANA: typing.ClassVar['InputSubset'] = ...
    FULLWIDTH_LATIN: typing.ClassVar['InputSubset'] = ...
    FULLWIDTH_DIGITS: typing.ClassVar['InputSubset'] = ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.im")``.

    InputContext: typing.Type[InputContext]
    InputMethodHighlight: typing.Type[InputMethodHighlight]
    InputMethodRequests: typing.Type[InputMethodRequests]
    InputSubset: typing.Type[InputSubset]
    spi: java.awt.im.spi.__module_protocol__



import java.awt
import java.awt.font
import java.awt.im
import java.lang
import java.text
import java.util
import javax.swing
import typing



class InputMethod:
    def activate(self) -> None: ...
    def deactivate(self, boolean: bool) -> None: ...
    def dispatchEvent(self, aWTEvent: java.awt.AWTEvent) -> None: ...
    def dispose(self) -> None: ...
    def endComposition(self) -> None: ...
    def getControlObject(self) -> typing.Any: ...
    def getLocale(self) -> java.util.Locale: ...
    def hideWindows(self) -> None: ...
    def isCompositionEnabled(self) -> bool: ...
    def notifyClientWindowChange(self, rectangle: java.awt.Rectangle) -> None: ...
    def reconvert(self) -> None: ...
    def removeNotify(self) -> None: ...
    def setCharacterSubsets(self, subsetArray: typing.List[java.lang.Character.Subset]) -> None: ...
    def setCompositionEnabled(self, boolean: bool) -> None: ...
    def setInputMethodContext(self, inputMethodContext: 'InputMethodContext') -> None: ...
    def setLocale(self, locale: java.util.Locale) -> bool: ...

class InputMethodContext(java.awt.im.InputMethodRequests):
    def createInputMethodJFrame(self, string: str, boolean: bool) -> javax.swing.JFrame: ...
    def createInputMethodWindow(self, string: str, boolean: bool) -> java.awt.Window: ...
    def dispatchInputMethodEvent(self, int: int, attributedCharacterIterator: java.text.AttributedCharacterIterator, int2: int, textHitInfo: java.awt.font.TextHitInfo, textHitInfo2: java.awt.font.TextHitInfo) -> None: ...
    def enableClientWindowNotification(self, inputMethod: InputMethod, boolean: bool) -> None: ...

class InputMethodDescriptor:
    def createInputMethod(self) -> InputMethod: ...
    def getAvailableLocales(self) -> typing.List[java.util.Locale]: ...
    def getInputMethodDisplayName(self, locale: java.util.Locale, locale2: java.util.Locale) -> str: ...
    def getInputMethodIcon(self, locale: java.util.Locale) -> java.awt.Image: ...
    def hasDynamicLocaleList(self) -> bool: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.im.spi")``.

    InputMethod: typing.Type[InputMethod]
    InputMethodContext: typing.Type[InputMethodContext]
    InputMethodDescriptor: typing.Type[InputMethodDescriptor]



import java.io
import java.lang
import java.lang.reflect
import java.nio
import java.util
import typing



class CallSite:
    def dynamicInvoker(self) -> 'MethodHandle': ...
    def getTarget(self) -> 'MethodHandle': ...
    def setTarget(self, methodHandle: 'MethodHandle') -> None: ...
    def type(self) -> 'MethodType': ...

class ConstantBootstraps:
    def __init__(self): ...
    @staticmethod
    def arrayVarHandle(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type['VarHandle'], class2: typing.Type[typing.Any]) -> 'VarHandle': ...
    _enumConstant__E = typing.TypeVar('_enumConstant__E', bound=java.lang.Enum)  # <E>
    @staticmethod
    def enumConstant(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type[_enumConstant__E]) -> _enumConstant__E: ...
    @staticmethod
    def fieldVarHandle(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type['VarHandle'], class2: typing.Type[typing.Any], class3: typing.Type[typing.Any]) -> 'VarHandle': ...
    @typing.overload
    @staticmethod
    def getStaticFinal(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type[typing.Any]) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def getStaticFinal(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type[typing.Any], class2: typing.Type[typing.Any]) -> typing.Any: ...
    @staticmethod
    def invoke(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type[typing.Any], methodHandle: 'MethodHandle', objectArray: typing.List[typing.Any]) -> typing.Any: ...
    @staticmethod
    def nullConstant(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type[typing.Any]) -> typing.Any: ...
    @staticmethod
    def primitiveClass(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type[typing.Any]) -> typing.Type[typing.Any]: ...
    @staticmethod
    def staticFieldVarHandle(lookup: 'MethodHandles.Lookup', string: str, class_: typing.Type['VarHandle'], class2: typing.Type[typing.Any], class3: typing.Type[typing.Any]) -> 'VarHandle': ...

class LambdaConversionException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable, boolean: bool, boolean2: bool): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class LambdaMetafactory:
    FLAG_SERIALIZABLE: typing.ClassVar[int] = ...
    FLAG_MARKERS: typing.ClassVar[int] = ...
    FLAG_BRIDGES: typing.ClassVar[int] = ...
    @staticmethod
    def altMetafactory(lookup: 'MethodHandles.Lookup', string: str, methodType: 'MethodType', objectArray: typing.List[typing.Any]) -> CallSite: ...
    @staticmethod
    def metafactory(lookup: 'MethodHandles.Lookup', string: str, methodType: 'MethodType', methodType2: 'MethodType', methodHandle: 'MethodHandle', methodType3: 'MethodType') -> CallSite: ...

class MethodHandle:
    @typing.overload
    def asCollector(self, int: int, class_: typing.Type[typing.Any], int2: int) -> 'MethodHandle': ...
    @typing.overload
    def asCollector(self, class_: typing.Type[typing.Any], int: int) -> 'MethodHandle': ...
    def asFixedArity(self) -> 'MethodHandle': ...
    @typing.overload
    def asSpreader(self, int: int, class_: typing.Type[typing.Any], int2: int) -> 'MethodHandle': ...
    @typing.overload
    def asSpreader(self, class_: typing.Type[typing.Any], int: int) -> 'MethodHandle': ...
    def asType(self, methodType: 'MethodType') -> 'MethodHandle': ...
    def asVarargsCollector(self, class_: typing.Type[typing.Any]) -> 'MethodHandle': ...
    def bindTo(self, object: typing.Any) -> 'MethodHandle': ...
    def invoke(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def invokeExact(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    @typing.overload
    def invokeWithArguments(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    @typing.overload
    def invokeWithArguments(self, list: java.util.List[typing.Any]) -> typing.Any: ...
    def isVarargsCollector(self) -> bool: ...
    def toString(self) -> str: ...
    def type(self) -> 'MethodType': ...
    def withVarargs(self, boolean: bool) -> 'MethodHandle': ...

class MethodHandleInfo:
    REF_getField: typing.ClassVar[int] = ...
    REF_getStatic: typing.ClassVar[int] = ...
    REF_putField: typing.ClassVar[int] = ...
    REF_putStatic: typing.ClassVar[int] = ...
    REF_invokeVirtual: typing.ClassVar[int] = ...
    REF_invokeStatic: typing.ClassVar[int] = ...
    REF_invokeSpecial: typing.ClassVar[int] = ...
    REF_newInvokeSpecial: typing.ClassVar[int] = ...
    REF_invokeInterface: typing.ClassVar[int] = ...
    def getDeclaringClass(self) -> typing.Type[typing.Any]: ...
    def getMethodType(self) -> 'MethodType': ...
    def getModifiers(self) -> int: ...
    def getName(self) -> str: ...
    def getReferenceKind(self) -> int: ...
    def isVarArgs(self) -> bool: ...
    @staticmethod
    def referenceKindToString(int: int) -> str: ...
    _reflectAs__T = typing.TypeVar('_reflectAs__T', bound=java.lang.reflect.Member)  # <T>
    def reflectAs(self, class_: typing.Type[_reflectAs__T], lookup: 'MethodHandles.Lookup') -> _reflectAs__T: ...
    @staticmethod
    def toString(int: int, class_: typing.Type[typing.Any], string: str, methodType: 'MethodType') -> str: ...

class MethodHandleProxies:
    _asInterfaceInstance__T = typing.TypeVar('_asInterfaceInstance__T')  # <T>
    @staticmethod
    def asInterfaceInstance(class_: typing.Type[_asInterfaceInstance__T], methodHandle: MethodHandle) -> _asInterfaceInstance__T: ...
    @staticmethod
    def isWrapperInstance(object: typing.Any) -> bool: ...
    @staticmethod
    def wrapperInstanceTarget(object: typing.Any) -> MethodHandle: ...
    @staticmethod
    def wrapperInstanceType(object: typing.Any) -> typing.Type[typing.Any]: ...

class MethodHandles:
    @staticmethod
    def arrayConstructor(class_: typing.Type[typing.Any]) -> MethodHandle: ...
    @staticmethod
    def arrayElementGetter(class_: typing.Type[typing.Any]) -> MethodHandle: ...
    @staticmethod
    def arrayElementSetter(class_: typing.Type[typing.Any]) -> MethodHandle: ...
    @staticmethod
    def arrayElementVarHandle(class_: typing.Type[typing.Any]) -> 'VarHandle': ...
    @staticmethod
    def arrayLength(class_: typing.Type[typing.Any]) -> MethodHandle: ...
    @staticmethod
    def byteArrayViewVarHandle(class_: typing.Type[typing.Any], byteOrder: java.nio.ByteOrder) -> 'VarHandle': ...
    @staticmethod
    def byteBufferViewVarHandle(class_: typing.Type[typing.Any], byteOrder: java.nio.ByteOrder) -> 'VarHandle': ...
    @staticmethod
    def catchException(methodHandle: MethodHandle, class_: typing.Type[java.lang.Throwable], methodHandle2: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def collectArguments(methodHandle: MethodHandle, int: int, methodHandle2: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def constant(class_: typing.Type[typing.Any], object: typing.Any) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def countedLoop(methodHandle: MethodHandle, methodHandle2: MethodHandle, methodHandle3: MethodHandle) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def countedLoop(methodHandle: MethodHandle, methodHandle2: MethodHandle, methodHandle3: MethodHandle, methodHandle4: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def doWhileLoop(methodHandle: MethodHandle, methodHandle2: MethodHandle, methodHandle3: MethodHandle) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def dropArguments(methodHandle: MethodHandle, int: int, classArray: typing.List[typing.Type[typing.Any]]) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def dropArguments(methodHandle: MethodHandle, int: int, list: java.util.List[typing.Type[typing.Any]]) -> MethodHandle: ...
    @staticmethod
    def dropArgumentsToMatch(methodHandle: MethodHandle, int: int, list: java.util.List[typing.Type[typing.Any]], int2: int) -> MethodHandle: ...
    @staticmethod
    def empty(methodType: 'MethodType') -> MethodHandle: ...
    @staticmethod
    def exactInvoker(methodType: 'MethodType') -> MethodHandle: ...
    @staticmethod
    def explicitCastArguments(methodHandle: MethodHandle, methodType: 'MethodType') -> MethodHandle: ...
    @staticmethod
    def filterArguments(methodHandle: MethodHandle, int: int, methodHandleArray: typing.List[MethodHandle]) -> MethodHandle: ...
    @staticmethod
    def filterReturnValue(methodHandle: MethodHandle, methodHandle2: MethodHandle) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def foldArguments(methodHandle: MethodHandle, int: int, methodHandle2: MethodHandle) -> MethodHandle: ...
    @typing.overload
    @staticmethod
    def foldArguments(methodHandle: MethodHandle, methodHandle2: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def guardWithTest(methodHandle: MethodHandle, methodHandle2: MethodHandle, methodHandle3: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def identity(class_: typing.Type[typing.Any]) -> MethodHandle: ...
    @staticmethod
    def insertArguments(methodHandle: MethodHandle, int: int, objectArray: typing.List[typing.Any]) -> MethodHandle: ...
    @staticmethod
    def invoker(methodType: 'MethodType') -> MethodHandle: ...
    @staticmethod
    def iteratedLoop(methodHandle: MethodHandle, methodHandle2: MethodHandle, methodHandle3: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def lookup() -> 'MethodHandles.Lookup': ...
    @staticmethod
    def loop(methodHandleArray: typing.List[typing.List[MethodHandle]]) -> MethodHandle: ...
    @staticmethod
    def permuteArguments(methodHandle: MethodHandle, methodType: 'MethodType', intArray: typing.List[int]) -> MethodHandle: ...
    @staticmethod
    def privateLookupIn(class_: typing.Type[typing.Any], lookup: 'MethodHandles.Lookup') -> 'MethodHandles.Lookup': ...
    @staticmethod
    def publicLookup() -> 'MethodHandles.Lookup': ...
    _reflectAs__T = typing.TypeVar('_reflectAs__T', bound=java.lang.reflect.Member)  # <T>
    @staticmethod
    def reflectAs(class_: typing.Type[_reflectAs__T], methodHandle: MethodHandle) -> _reflectAs__T: ...
    @staticmethod
    def spreadInvoker(methodType: 'MethodType', int: int) -> MethodHandle: ...
    @staticmethod
    def throwException(class_: typing.Type[typing.Any], class2: typing.Type[java.lang.Throwable]) -> MethodHandle: ...
    @staticmethod
    def tryFinally(methodHandle: MethodHandle, methodHandle2: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def varHandleExactInvoker(accessMode: 'VarHandle.AccessMode', methodType: 'MethodType') -> MethodHandle: ...
    @staticmethod
    def varHandleInvoker(accessMode: 'VarHandle.AccessMode', methodType: 'MethodType') -> MethodHandle: ...
    @staticmethod
    def whileLoop(methodHandle: MethodHandle, methodHandle2: MethodHandle, methodHandle3: MethodHandle) -> MethodHandle: ...
    @staticmethod
    def zero(class_: typing.Type[typing.Any]) -> MethodHandle: ...
    class Lookup:
        PUBLIC: typing.ClassVar[int] = ...
        PRIVATE: typing.ClassVar[int] = ...
        PROTECTED: typing.ClassVar[int] = ...
        PACKAGE: typing.ClassVar[int] = ...
        MODULE: typing.ClassVar[int] = ...
        UNCONDITIONAL: typing.ClassVar[int] = ...
        def accessClass(self, class_: typing.Type[typing.Any]) -> typing.Type[typing.Any]: ...
        def bind(self, object: typing.Any, string: str, methodType: 'MethodType') -> MethodHandle: ...
        def defineClass(self, byteArray: typing.List[int]) -> typing.Type[typing.Any]: ...
        def dropLookupMode(self, int: int) -> 'MethodHandles.Lookup': ...
        def findClass(self, string: str) -> typing.Type[typing.Any]: ...
        def findConstructor(self, class_: typing.Type[typing.Any], methodType: 'MethodType') -> MethodHandle: ...
        def findGetter(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any]) -> MethodHandle: ...
        def findSetter(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any]) -> MethodHandle: ...
        def findSpecial(self, class_: typing.Type[typing.Any], string: str, methodType: 'MethodType', class2: typing.Type[typing.Any]) -> MethodHandle: ...
        def findStatic(self, class_: typing.Type[typing.Any], string: str, methodType: 'MethodType') -> MethodHandle: ...
        def findStaticGetter(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any]) -> MethodHandle: ...
        def findStaticSetter(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any]) -> MethodHandle: ...
        def findStaticVarHandle(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any]) -> 'VarHandle': ...
        def findVarHandle(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any]) -> 'VarHandle': ...
        def findVirtual(self, class_: typing.Type[typing.Any], string: str, methodType: 'MethodType') -> MethodHandle: ...
        def hasPrivateAccess(self) -> bool: ...
        def lookupClass(self) -> typing.Type[typing.Any]: ...
        def lookupModes(self) -> int: ...
        def revealDirect(self, methodHandle: MethodHandle) -> MethodHandleInfo: ...
        def toString(self) -> str: ...
        def unreflect(self, method: java.lang.reflect.Method) -> MethodHandle: ...
        def unreflectConstructor(self, constructor: java.lang.reflect.Constructor[typing.Any]) -> MethodHandle: ...
        def unreflectGetter(self, field: java.lang.reflect.Field) -> MethodHandle: ...
        def unreflectSetter(self, field: java.lang.reflect.Field) -> MethodHandle: ...
        def unreflectSpecial(self, method: java.lang.reflect.Method, class_: typing.Type[typing.Any]) -> MethodHandle: ...
        def unreflectVarHandle(self, field: java.lang.reflect.Field) -> 'VarHandle': ...

class MethodType(java.io.Serializable):
    @typing.overload
    def appendParameterTypes(self, classArray: typing.List[typing.Type[typing.Any]]) -> 'MethodType': ...
    @typing.overload
    def appendParameterTypes(self, list: java.util.List[typing.Type[typing.Any]]) -> 'MethodType': ...
    def changeParameterType(self, int: int, class_: typing.Type[typing.Any]) -> 'MethodType': ...
    def changeReturnType(self, class_: typing.Type[typing.Any]) -> 'MethodType': ...
    def dropParameterTypes(self, int: int, int2: int) -> 'MethodType': ...
    def equals(self, object: typing.Any) -> bool: ...
    def erase(self) -> 'MethodType': ...
    @staticmethod
    def fromMethodDescriptorString(string: str, classLoader: java.lang.ClassLoader) -> 'MethodType': ...
    def generic(self) -> 'MethodType': ...
    @typing.overload
    @staticmethod
    def genericMethodType(int: int) -> 'MethodType': ...
    @typing.overload
    @staticmethod
    def genericMethodType(int: int, boolean: bool) -> 'MethodType': ...
    def hasPrimitives(self) -> bool: ...
    def hasWrappers(self) -> bool: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def insertParameterTypes(self, int: int, classArray: typing.List[typing.Type[typing.Any]]) -> 'MethodType': ...
    @typing.overload
    def insertParameterTypes(self, int: int, list: java.util.List[typing.Type[typing.Any]]) -> 'MethodType': ...
    def lastParameterType(self) -> typing.Type[typing.Any]: ...
    @typing.overload
    @staticmethod
    def methodType(class_: typing.Type[typing.Any]) -> 'MethodType': ...
    @typing.overload
    @staticmethod
    def methodType(class_: typing.Type[typing.Any], class2: typing.Type[typing.Any]) -> 'MethodType': ...
    @typing.overload
    @staticmethod
    def methodType(class_: typing.Type[typing.Any], class2: typing.Type[typing.Any], classArray: typing.List[typing.Type[typing.Any]]) -> 'MethodType': ...
    @typing.overload
    @staticmethod
    def methodType(class_: typing.Type[typing.Any], classArray: typing.List[typing.Type[typing.Any]]) -> 'MethodType': ...
    @typing.overload
    @staticmethod
    def methodType(class_: typing.Type[typing.Any], methodType: 'MethodType') -> 'MethodType': ...
    @typing.overload
    @staticmethod
    def methodType(class_: typing.Type[typing.Any], list: java.util.List[typing.Type[typing.Any]]) -> 'MethodType': ...
    def parameterArray(self) -> typing.List[typing.Type[typing.Any]]: ...
    def parameterCount(self) -> int: ...
    def parameterList(self) -> java.util.List[typing.Type[typing.Any]]: ...
    def parameterType(self, int: int) -> typing.Type[typing.Any]: ...
    def returnType(self) -> typing.Type[typing.Any]: ...
    def toMethodDescriptorString(self) -> str: ...
    def toString(self) -> str: ...
    def unwrap(self) -> 'MethodType': ...
    def wrap(self) -> 'MethodType': ...

class SerializedLambda(java.io.Serializable):
    def __init__(self, class_: typing.Type[typing.Any], string: str, string2: str, string3: str, int: int, string4: str, string5: str, string6: str, string7: str, objectArray: typing.List[typing.Any]): ...
    def getCapturedArg(self, int: int) -> typing.Any: ...
    def getCapturedArgCount(self) -> int: ...
    def getCapturingClass(self) -> str: ...
    def getFunctionalInterfaceClass(self) -> str: ...
    def getFunctionalInterfaceMethodName(self) -> str: ...
    def getFunctionalInterfaceMethodSignature(self) -> str: ...
    def getImplClass(self) -> str: ...
    def getImplMethodKind(self) -> int: ...
    def getImplMethodName(self) -> str: ...
    def getImplMethodSignature(self) -> str: ...
    def getInstantiatedMethodType(self) -> str: ...
    def toString(self) -> str: ...

class StringConcatException(java.lang.Exception):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...

class StringConcatFactory:
    @staticmethod
    def makeConcat(lookup: MethodHandles.Lookup, string: str, methodType: MethodType) -> CallSite: ...
    @staticmethod
    def makeConcatWithConstants(lookup: MethodHandles.Lookup, string: str, methodType: MethodType, string2: str, objectArray: typing.List[typing.Any]) -> CallSite: ...

class SwitchPoint:
    def __init__(self): ...
    def guardWithTest(self, methodHandle: MethodHandle, methodHandle2: MethodHandle) -> MethodHandle: ...
    def hasBeenInvalidated(self) -> bool: ...
    @staticmethod
    def invalidateAll(switchPointArray: typing.List['SwitchPoint']) -> None: ...

class VarHandle:
    def accessModeType(self, accessMode: 'VarHandle.AccessMode') -> MethodType: ...
    @staticmethod
    def acquireFence() -> None: ...
    def compareAndExchange(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def compareAndExchangeAcquire(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def compareAndExchangeRelease(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def compareAndSet(self, objectArray: typing.List[typing.Any]) -> bool: ...
    def coordinateTypes(self) -> java.util.List[typing.Type[typing.Any]]: ...
    @staticmethod
    def fullFence() -> None: ...
    def get(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAcquire(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndAdd(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndAddAcquire(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndAddRelease(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseAnd(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseAndAcquire(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseAndRelease(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseOr(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseOrAcquire(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseOrRelease(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseXor(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseXorAcquire(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndBitwiseXorRelease(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndSet(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndSetAcquire(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getAndSetRelease(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getOpaque(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def getVolatile(self, objectArray: typing.List[typing.Any]) -> typing.Any: ...
    def isAccessModeSupported(self, accessMode: 'VarHandle.AccessMode') -> bool: ...
    @staticmethod
    def loadLoadFence() -> None: ...
    @staticmethod
    def releaseFence() -> None: ...
    def set(self, objectArray: typing.List[typing.Any]) -> None: ...
    def setOpaque(self, objectArray: typing.List[typing.Any]) -> None: ...
    def setRelease(self, objectArray: typing.List[typing.Any]) -> None: ...
    def setVolatile(self, objectArray: typing.List[typing.Any]) -> None: ...
    @staticmethod
    def storeStoreFence() -> None: ...
    def toMethodHandle(self, accessMode: 'VarHandle.AccessMode') -> MethodHandle: ...
    def varType(self) -> typing.Type[typing.Any]: ...
    def weakCompareAndSet(self, objectArray: typing.List[typing.Any]) -> bool: ...
    def weakCompareAndSetAcquire(self, objectArray: typing.List[typing.Any]) -> bool: ...
    def weakCompareAndSetPlain(self, objectArray: typing.List[typing.Any]) -> bool: ...
    def weakCompareAndSetRelease(self, objectArray: typing.List[typing.Any]) -> bool: ...
    class AccessMode(java.lang.Enum['VarHandle.AccessMode']):
        GET: typing.ClassVar['VarHandle.AccessMode'] = ...
        SET: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_VOLATILE: typing.ClassVar['VarHandle.AccessMode'] = ...
        SET_VOLATILE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        SET_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_OPAQUE: typing.ClassVar['VarHandle.AccessMode'] = ...
        SET_OPAQUE: typing.ClassVar['VarHandle.AccessMode'] = ...
        COMPARE_AND_SET: typing.ClassVar['VarHandle.AccessMode'] = ...
        COMPARE_AND_EXCHANGE: typing.ClassVar['VarHandle.AccessMode'] = ...
        COMPARE_AND_EXCHANGE_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        COMPARE_AND_EXCHANGE_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        WEAK_COMPARE_AND_SET_PLAIN: typing.ClassVar['VarHandle.AccessMode'] = ...
        WEAK_COMPARE_AND_SET: typing.ClassVar['VarHandle.AccessMode'] = ...
        WEAK_COMPARE_AND_SET_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        WEAK_COMPARE_AND_SET_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_SET: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_SET_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_SET_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_ADD: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_ADD_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_ADD_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_OR: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_OR_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_OR_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_AND: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_AND_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_AND_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_XOR: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_XOR_RELEASE: typing.ClassVar['VarHandle.AccessMode'] = ...
        GET_AND_BITWISE_XOR_ACQUIRE: typing.ClassVar['VarHandle.AccessMode'] = ...
        def methodName(self) -> str: ...
        @staticmethod
        def valueFromMethodName(string: str) -> 'VarHandle.AccessMode': ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'VarHandle.AccessMode': ...
        @staticmethod
        def values() -> typing.List['VarHandle.AccessMode']: ...

class WrongMethodTypeException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class ConstantCallSite(CallSite):
    def __init__(self, methodHandle: MethodHandle): ...
    def dynamicInvoker(self) -> MethodHandle: ...
    def getTarget(self) -> MethodHandle: ...
    def setTarget(self, methodHandle: MethodHandle) -> None: ...

class MutableCallSite(CallSite):
    @typing.overload
    def __init__(self, methodHandle: MethodHandle): ...
    @typing.overload
    def __init__(self, methodType: MethodType): ...
    def dynamicInvoker(self) -> MethodHandle: ...
    def getTarget(self) -> MethodHandle: ...
    def setTarget(self, methodHandle: MethodHandle) -> None: ...
    @staticmethod
    def syncAll(mutableCallSiteArray: typing.List['MutableCallSite']) -> None: ...

class VolatileCallSite(CallSite):
    @typing.overload
    def __init__(self, methodHandle: MethodHandle): ...
    @typing.overload
    def __init__(self, methodType: MethodType): ...
    def dynamicInvoker(self) -> MethodHandle: ...
    def getTarget(self) -> MethodHandle: ...
    def setTarget(self, methodHandle: MethodHandle) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.lang.invoke")``.

    CallSite: typing.Type[CallSite]
    ConstantBootstraps: typing.Type[ConstantBootstraps]
    ConstantCallSite: typing.Type[ConstantCallSite]
    LambdaConversionException: typing.Type[LambdaConversionException]
    LambdaMetafactory: typing.Type[LambdaMetafactory]
    MethodHandle: typing.Type[MethodHandle]
    MethodHandleInfo: typing.Type[MethodHandleInfo]
    MethodHandleProxies: typing.Type[MethodHandleProxies]
    MethodHandles: typing.Type[MethodHandles]
    MethodType: typing.Type[MethodType]
    MutableCallSite: typing.Type[MutableCallSite]
    SerializedLambda: typing.Type[SerializedLambda]
    StringConcatException: typing.Type[StringConcatException]
    StringConcatFactory: typing.Type[StringConcatFactory]
    SwitchPoint: typing.Type[SwitchPoint]
    VarHandle: typing.Type[VarHandle]
    VolatileCallSite: typing.Type[VolatileCallSite]
    WrongMethodTypeException: typing.Type[WrongMethodTypeException]



import java.io
import java.lang
import java.math
import java.text.spi
import java.util
import typing



class Annotation:
    def __init__(self, object: typing.Any): ...
    def getValue(self) -> typing.Any: ...
    def toString(self) -> str: ...

class AttributedString:
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, map: typing.Union[java.util.Map['AttributedCharacterIterator.Attribute', typing.Any], typing.Mapping['AttributedCharacterIterator.Attribute', typing.Any]]): ...
    @typing.overload
    def __init__(self, attributedCharacterIterator: 'AttributedCharacterIterator'): ...
    @typing.overload
    def __init__(self, attributedCharacterIterator: 'AttributedCharacterIterator', int: int, int2: int): ...
    @typing.overload
    def __init__(self, attributedCharacterIterator: 'AttributedCharacterIterator', int: int, int2: int, attributeArray: typing.List['AttributedCharacterIterator.Attribute']): ...
    @typing.overload
    def addAttribute(self, attribute: 'AttributedCharacterIterator.Attribute', object: typing.Any) -> None: ...
    @typing.overload
    def addAttribute(self, attribute: 'AttributedCharacterIterator.Attribute', object: typing.Any, int: int, int2: int) -> None: ...
    def addAttributes(self, map: typing.Union[java.util.Map['AttributedCharacterIterator.Attribute', typing.Any], typing.Mapping['AttributedCharacterIterator.Attribute', typing.Any]], int: int, int2: int) -> None: ...
    @typing.overload
    def getIterator(self) -> 'AttributedCharacterIterator': ...
    @typing.overload
    def getIterator(self, attributeArray: typing.List['AttributedCharacterIterator.Attribute']) -> 'AttributedCharacterIterator': ...
    @typing.overload
    def getIterator(self, attributeArray: typing.List['AttributedCharacterIterator.Attribute'], int: int, int2: int) -> 'AttributedCharacterIterator': ...

class Bidi:
    DIRECTION_LEFT_TO_RIGHT: typing.ClassVar[int] = ...
    DIRECTION_RIGHT_TO_LEFT: typing.ClassVar[int] = ...
    DIRECTION_DEFAULT_LEFT_TO_RIGHT: typing.ClassVar[int] = ...
    DIRECTION_DEFAULT_RIGHT_TO_LEFT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, charArray: typing.List[str], int: int, byteArray: typing.List[int], int2: int, int3: int, int4: int): ...
    @typing.overload
    def __init__(self, string: str, int: int): ...
    @typing.overload
    def __init__(self, attributedCharacterIterator: 'AttributedCharacterIterator'): ...
    def baseIsLeftToRight(self) -> bool: ...
    def createLineBidi(self, int: int, int2: int) -> 'Bidi': ...
    def getBaseLevel(self) -> int: ...
    def getLength(self) -> int: ...
    def getLevelAt(self, int: int) -> int: ...
    def getRunCount(self) -> int: ...
    def getRunLevel(self, int: int) -> int: ...
    def getRunLimit(self, int: int) -> int: ...
    def getRunStart(self, int: int) -> int: ...
    def isLeftToRight(self) -> bool: ...
    def isMixed(self) -> bool: ...
    def isRightToLeft(self) -> bool: ...
    @staticmethod
    def reorderVisually(byteArray: typing.List[int], int: int, objectArray: typing.List[typing.Any], int2: int, int3: int) -> None: ...
    @staticmethod
    def requiresBidi(charArray: typing.List[str], int: int, int2: int) -> bool: ...
    def toString(self) -> str: ...

class BreakIterator(java.lang.Cloneable):
    DONE: typing.ClassVar[int] = ...
    def clone(self) -> typing.Any: ...
    def current(self) -> int: ...
    def first(self) -> int: ...
    def following(self, int: int) -> int: ...
    @staticmethod
    def getAvailableLocales() -> typing.List[java.util.Locale]: ...
    @typing.overload
    @staticmethod
    def getCharacterInstance() -> 'BreakIterator': ...
    @typing.overload
    @staticmethod
    def getCharacterInstance(locale: java.util.Locale) -> 'BreakIterator': ...
    @typing.overload
    @staticmethod
    def getLineInstance() -> 'BreakIterator': ...
    @typing.overload
    @staticmethod
    def getLineInstance(locale: java.util.Locale) -> 'BreakIterator': ...
    @typing.overload
    @staticmethod
    def getSentenceInstance() -> 'BreakIterator': ...
    @typing.overload
    @staticmethod
    def getSentenceInstance(locale: java.util.Locale) -> 'BreakIterator': ...
    def getText(self) -> 'CharacterIterator': ...
    @typing.overload
    @staticmethod
    def getWordInstance() -> 'BreakIterator': ...
    @typing.overload
    @staticmethod
    def getWordInstance(locale: java.util.Locale) -> 'BreakIterator': ...
    def isBoundary(self, int: int) -> bool: ...
    def last(self) -> int: ...
    @typing.overload
    def next(self) -> int: ...
    @typing.overload
    def next(self, int: int) -> int: ...
    def preceding(self, int: int) -> int: ...
    def previous(self) -> int: ...
    @typing.overload
    def setText(self, characterIterator: 'CharacterIterator') -> None: ...
    @typing.overload
    def setText(self, string: str) -> None: ...

class CharacterIterator(java.lang.Cloneable):
    DONE: typing.ClassVar[str] = ...
    def clone(self) -> typing.Any: ...
    def current(self) -> str: ...
    def first(self) -> str: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def last(self) -> str: ...
    def next(self) -> str: ...
    def previous(self) -> str: ...
    def setIndex(self, int: int) -> str: ...

class CollationElementIterator:
    NULLORDER: typing.ClassVar[int] = ...
    def getMaxExpansion(self, int: int) -> int: ...
    def getOffset(self) -> int: ...
    def next(self) -> int: ...
    def previous(self) -> int: ...
    @staticmethod
    def primaryOrder(int: int) -> int: ...
    def reset(self) -> None: ...
    @staticmethod
    def secondaryOrder(int: int) -> int: ...
    def setOffset(self, int: int) -> None: ...
    @typing.overload
    def setText(self, string: str) -> None: ...
    @typing.overload
    def setText(self, characterIterator: CharacterIterator) -> None: ...
    @staticmethod
    def tertiaryOrder(int: int) -> int: ...

class CollationKey(java.lang.Comparable['CollationKey']):
    def compareTo(self, collationKey: 'CollationKey') -> int: ...
    def getSourceString(self) -> str: ...
    def toByteArray(self) -> typing.List[int]: ...

class Collator(java.util.Comparator[typing.Any], java.lang.Cloneable):
    PRIMARY: typing.ClassVar[int] = ...
    SECONDARY: typing.ClassVar[int] = ...
    TERTIARY: typing.ClassVar[int] = ...
    IDENTICAL: typing.ClassVar[int] = ...
    NO_DECOMPOSITION: typing.ClassVar[int] = ...
    CANONICAL_DECOMPOSITION: typing.ClassVar[int] = ...
    FULL_DECOMPOSITION: typing.ClassVar[int] = ...
    def clone(self) -> typing.Any: ...
    @typing.overload
    def compare(self, string: str, string2: str) -> int: ...
    @typing.overload
    def compare(self, object: typing.Any, object2: typing.Any) -> int: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def equals(self, string: str, string2: str) -> bool: ...
    @staticmethod
    def getAvailableLocales() -> typing.List[java.util.Locale]: ...
    def getCollationKey(self, string: str) -> CollationKey: ...
    def getDecomposition(self) -> int: ...
    @typing.overload
    @staticmethod
    def getInstance(locale: java.util.Locale) -> 'Collator': ...
    @typing.overload
    @staticmethod
    def getInstance() -> 'Collator': ...
    def getStrength(self) -> int: ...
    def hashCode(self) -> int: ...
    def setDecomposition(self, int: int) -> None: ...
    def setStrength(self, int: int) -> None: ...

class DateFormatSymbols(java.io.Serializable, java.lang.Cloneable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, locale: java.util.Locale): ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAmPmStrings(self) -> typing.List[str]: ...
    @staticmethod
    def getAvailableLocales() -> typing.List[java.util.Locale]: ...
    def getEras(self) -> typing.List[str]: ...
    @typing.overload
    @staticmethod
    def getInstance() -> 'DateFormatSymbols': ...
    @typing.overload
    @staticmethod
    def getInstance(locale: java.util.Locale) -> 'DateFormatSymbols': ...
    def getLocalPatternChars(self) -> str: ...
    def getMonths(self) -> typing.List[str]: ...
    def getShortMonths(self) -> typing.List[str]: ...
    def getShortWeekdays(self) -> typing.List[str]: ...
    def getWeekdays(self) -> typing.List[str]: ...
    def getZoneStrings(self) -> typing.List[typing.List[str]]: ...
    def hashCode(self) -> int: ...
    def setAmPmStrings(self, stringArray: typing.List[str]) -> None: ...
    def setEras(self, stringArray: typing.List[str]) -> None: ...
    def setLocalPatternChars(self, string: str) -> None: ...
    def setMonths(self, stringArray: typing.List[str]) -> None: ...
    def setShortMonths(self, stringArray: typing.List[str]) -> None: ...
    def setShortWeekdays(self, stringArray: typing.List[str]) -> None: ...
    def setWeekdays(self, stringArray: typing.List[str]) -> None: ...
    def setZoneStrings(self, stringArray: typing.List[typing.List[str]]) -> None: ...

class DecimalFormatSymbols(java.lang.Cloneable, java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, locale: java.util.Locale): ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    @staticmethod
    def getAvailableLocales() -> typing.List[java.util.Locale]: ...
    def getCurrency(self) -> java.util.Currency: ...
    def getCurrencySymbol(self) -> str: ...
    def getDecimalSeparator(self) -> str: ...
    def getDigit(self) -> str: ...
    def getExponentSeparator(self) -> str: ...
    def getGroupingSeparator(self) -> str: ...
    def getInfinity(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance() -> 'DecimalFormatSymbols': ...
    @typing.overload
    @staticmethod
    def getInstance(locale: java.util.Locale) -> 'DecimalFormatSymbols': ...
    def getInternationalCurrencySymbol(self) -> str: ...
    def getMinusSign(self) -> str: ...
    def getMonetaryDecimalSeparator(self) -> str: ...
    def getNaN(self) -> str: ...
    def getPatternSeparator(self) -> str: ...
    def getPerMill(self) -> str: ...
    def getPercent(self) -> str: ...
    def getZeroDigit(self) -> str: ...
    def hashCode(self) -> int: ...
    def setCurrency(self, currency: java.util.Currency) -> None: ...
    def setCurrencySymbol(self, string: str) -> None: ...
    def setDecimalSeparator(self, char: str) -> None: ...
    def setDigit(self, char: str) -> None: ...
    def setExponentSeparator(self, string: str) -> None: ...
    def setGroupingSeparator(self, char: str) -> None: ...
    def setInfinity(self, string: str) -> None: ...
    def setInternationalCurrencySymbol(self, string: str) -> None: ...
    def setMinusSign(self, char: str) -> None: ...
    def setMonetaryDecimalSeparator(self, char: str) -> None: ...
    def setNaN(self, string: str) -> None: ...
    def setPatternSeparator(self, char: str) -> None: ...
    def setPerMill(self, char: str) -> None: ...
    def setPercent(self, char: str) -> None: ...
    def setZeroDigit(self, char: str) -> None: ...

class FieldPosition:
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, field: 'Format.Field'): ...
    @typing.overload
    def __init__(self, field: 'Format.Field', int: int): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getField(self) -> int: ...
    def getFieldAttribute(self) -> 'Format.Field': ...
    def hashCode(self) -> int: ...
    def setBeginIndex(self, int: int) -> None: ...
    def setEndIndex(self, int: int) -> None: ...
    def toString(self) -> str: ...

class Normalizer:
    @staticmethod
    def isNormalized(charSequence: typing.Union[java.lang.CharSequence, str], form: 'Normalizer.Form') -> bool: ...
    @staticmethod
    def normalize(charSequence: typing.Union[java.lang.CharSequence, str], form: 'Normalizer.Form') -> str: ...
    class Form(java.lang.Enum['Normalizer.Form']):
        NFD: typing.ClassVar['Normalizer.Form'] = ...
        NFC: typing.ClassVar['Normalizer.Form'] = ...
        NFKD: typing.ClassVar['Normalizer.Form'] = ...
        NFKC: typing.ClassVar['Normalizer.Form'] = ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'Normalizer.Form': ...
        @staticmethod
        def values() -> typing.List['Normalizer.Form']: ...

class ParseException(java.lang.Exception):
    def __init__(self, string: str, int: int): ...
    def getErrorOffset(self) -> int: ...

class ParsePosition:
    def __init__(self, int: int): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getErrorIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def setErrorIndex(self, int: int) -> None: ...
    def setIndex(self, int: int) -> None: ...
    def toString(self) -> str: ...

class AttributedCharacterIterator(CharacterIterator):
    def getAllAttributeKeys(self) -> java.util.Set['AttributedCharacterIterator.Attribute']: ...
    def getAttribute(self, attribute: 'AttributedCharacterIterator.Attribute') -> typing.Any: ...
    def getAttributes(self) -> java.util.Map['AttributedCharacterIterator.Attribute', typing.Any]: ...
    @typing.overload
    def getRunLimit(self) -> int: ...
    @typing.overload
    def getRunLimit(self, attribute: 'AttributedCharacterIterator.Attribute') -> int: ...
    @typing.overload
    def getRunLimit(self, set: java.util.Set['AttributedCharacterIterator.Attribute']) -> int: ...
    @typing.overload
    def getRunStart(self) -> int: ...
    @typing.overload
    def getRunStart(self, attribute: 'AttributedCharacterIterator.Attribute') -> int: ...
    @typing.overload
    def getRunStart(self, set: java.util.Set['AttributedCharacterIterator.Attribute']) -> int: ...
    class Attribute(java.io.Serializable):
        LANGUAGE: typing.ClassVar['AttributedCharacterIterator.Attribute'] = ...
        READING: typing.ClassVar['AttributedCharacterIterator.Attribute'] = ...
        INPUT_METHOD_SEGMENT: typing.ClassVar['AttributedCharacterIterator.Attribute'] = ...
        def equals(self, object: typing.Any) -> bool: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...

class RuleBasedCollator(Collator):
    def __init__(self, string: str): ...
    def clone(self) -> typing.Any: ...
    @typing.overload
    def compare(self, object: typing.Any, object2: typing.Any) -> int: ...
    @typing.overload
    def compare(self, string: str, string2: str) -> int: ...
    @typing.overload
    def equals(self, string: str, string2: str) -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def getCollationElementIterator(self, string: str) -> CollationElementIterator: ...
    @typing.overload
    def getCollationElementIterator(self, characterIterator: CharacterIterator) -> CollationElementIterator: ...
    def getCollationKey(self, string: str) -> CollationKey: ...
    def getRules(self) -> str: ...
    def hashCode(self) -> int: ...

class StringCharacterIterator(CharacterIterator):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, int: int): ...
    @typing.overload
    def __init__(self, string: str, int: int, int2: int, int3: int): ...
    def clone(self) -> typing.Any: ...
    def current(self) -> str: ...
    def equals(self, object: typing.Any) -> bool: ...
    def first(self) -> str: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def last(self) -> str: ...
    def next(self) -> str: ...
    def previous(self) -> str: ...
    def setIndex(self, int: int) -> str: ...
    def setText(self, string: str) -> None: ...

class Format(java.io.Serializable, java.lang.Cloneable):
    def clone(self) -> typing.Any: ...
    @typing.overload
    def format(self, object: typing.Any, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, object: typing.Any) -> str: ...
    def formatToCharacterIterator(self, object: typing.Any) -> AttributedCharacterIterator: ...
    @typing.overload
    def parseObject(self, string: str, parsePosition: ParsePosition) -> typing.Any: ...
    @typing.overload
    def parseObject(self, string: str) -> typing.Any: ...
    class Field(AttributedCharacterIterator.Attribute): ...

class DateFormat(Format):
    ERA_FIELD: typing.ClassVar[int] = ...
    YEAR_FIELD: typing.ClassVar[int] = ...
    MONTH_FIELD: typing.ClassVar[int] = ...
    DATE_FIELD: typing.ClassVar[int] = ...
    HOUR_OF_DAY1_FIELD: typing.ClassVar[int] = ...
    HOUR_OF_DAY0_FIELD: typing.ClassVar[int] = ...
    MINUTE_FIELD: typing.ClassVar[int] = ...
    SECOND_FIELD: typing.ClassVar[int] = ...
    MILLISECOND_FIELD: typing.ClassVar[int] = ...
    DAY_OF_WEEK_FIELD: typing.ClassVar[int] = ...
    DAY_OF_YEAR_FIELD: typing.ClassVar[int] = ...
    DAY_OF_WEEK_IN_MONTH_FIELD: typing.ClassVar[int] = ...
    WEEK_OF_YEAR_FIELD: typing.ClassVar[int] = ...
    WEEK_OF_MONTH_FIELD: typing.ClassVar[int] = ...
    AM_PM_FIELD: typing.ClassVar[int] = ...
    HOUR1_FIELD: typing.ClassVar[int] = ...
    HOUR0_FIELD: typing.ClassVar[int] = ...
    TIMEZONE_FIELD: typing.ClassVar[int] = ...
    FULL: typing.ClassVar[int] = ...
    LONG: typing.ClassVar[int] = ...
    MEDIUM: typing.ClassVar[int] = ...
    SHORT: typing.ClassVar[int] = ...
    DEFAULT: typing.ClassVar[int] = ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def format(self, date: java.util.Date, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, date: java.util.Date) -> str: ...
    @typing.overload
    def format(self, object: typing.Any) -> str: ...
    @typing.overload
    def format(self, object: typing.Any, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @staticmethod
    def getAvailableLocales() -> typing.List[java.util.Locale]: ...
    def getCalendar(self) -> java.util.Calendar: ...
    @typing.overload
    @staticmethod
    def getDateInstance() -> 'DateFormat': ...
    @typing.overload
    @staticmethod
    def getDateInstance(int: int) -> 'DateFormat': ...
    @typing.overload
    @staticmethod
    def getDateInstance(int: int, locale: java.util.Locale) -> 'DateFormat': ...
    @typing.overload
    @staticmethod
    def getDateTimeInstance() -> 'DateFormat': ...
    @typing.overload
    @staticmethod
    def getDateTimeInstance(int: int, int2: int) -> 'DateFormat': ...
    @typing.overload
    @staticmethod
    def getDateTimeInstance(int: int, int2: int, locale: java.util.Locale) -> 'DateFormat': ...
    @staticmethod
    def getInstance() -> 'DateFormat': ...
    def getNumberFormat(self) -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getTimeInstance() -> 'DateFormat': ...
    @typing.overload
    @staticmethod
    def getTimeInstance(int: int) -> 'DateFormat': ...
    @typing.overload
    @staticmethod
    def getTimeInstance(int: int, locale: java.util.Locale) -> 'DateFormat': ...
    def getTimeZone(self) -> java.util.TimeZone: ...
    def hashCode(self) -> int: ...
    def isLenient(self) -> bool: ...
    @typing.overload
    def parse(self, string: str, parsePosition: ParsePosition) -> java.util.Date: ...
    @typing.overload
    def parse(self, string: str) -> java.util.Date: ...
    @typing.overload
    def parseObject(self, string: str, parsePosition: ParsePosition) -> typing.Any: ...
    @typing.overload
    def parseObject(self, string: str) -> typing.Any: ...
    def setCalendar(self, calendar: java.util.Calendar) -> None: ...
    def setLenient(self, boolean: bool) -> None: ...
    def setNumberFormat(self, numberFormat: 'NumberFormat') -> None: ...
    def setTimeZone(self, timeZone: java.util.TimeZone) -> None: ...
    class Field(Format.Field):
        ERA: typing.ClassVar['DateFormat.Field'] = ...
        YEAR: typing.ClassVar['DateFormat.Field'] = ...
        MONTH: typing.ClassVar['DateFormat.Field'] = ...
        DAY_OF_MONTH: typing.ClassVar['DateFormat.Field'] = ...
        HOUR_OF_DAY1: typing.ClassVar['DateFormat.Field'] = ...
        HOUR_OF_DAY0: typing.ClassVar['DateFormat.Field'] = ...
        MINUTE: typing.ClassVar['DateFormat.Field'] = ...
        SECOND: typing.ClassVar['DateFormat.Field'] = ...
        MILLISECOND: typing.ClassVar['DateFormat.Field'] = ...
        DAY_OF_WEEK: typing.ClassVar['DateFormat.Field'] = ...
        DAY_OF_YEAR: typing.ClassVar['DateFormat.Field'] = ...
        DAY_OF_WEEK_IN_MONTH: typing.ClassVar['DateFormat.Field'] = ...
        WEEK_OF_YEAR: typing.ClassVar['DateFormat.Field'] = ...
        WEEK_OF_MONTH: typing.ClassVar['DateFormat.Field'] = ...
        AM_PM: typing.ClassVar['DateFormat.Field'] = ...
        HOUR1: typing.ClassVar['DateFormat.Field'] = ...
        HOUR0: typing.ClassVar['DateFormat.Field'] = ...
        TIME_ZONE: typing.ClassVar['DateFormat.Field'] = ...
        def getCalendarField(self) -> int: ...
        @staticmethod
        def ofCalendarField(int: int) -> 'DateFormat.Field': ...

class MessageFormat(Format):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, locale: java.util.Locale): ...
    def applyPattern(self, string: str) -> None: ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def format(self, object: typing.Any) -> str: ...
    @typing.overload
    def format(self, object: typing.Any, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, objectArray: typing.List[typing.Any], stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    @staticmethod
    def format(string: str, objectArray: typing.List[typing.Any]) -> str: ...
    def formatToCharacterIterator(self, object: typing.Any) -> AttributedCharacterIterator: ...
    def getFormats(self) -> typing.List[Format]: ...
    def getFormatsByArgumentIndex(self) -> typing.List[Format]: ...
    def getLocale(self) -> java.util.Locale: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def parse(self, string: str) -> typing.List[typing.Any]: ...
    @typing.overload
    def parse(self, string: str, parsePosition: ParsePosition) -> typing.List[typing.Any]: ...
    @typing.overload
    def parseObject(self, string: str) -> typing.Any: ...
    @typing.overload
    def parseObject(self, string: str, parsePosition: ParsePosition) -> typing.Any: ...
    def setFormat(self, int: int, format: Format) -> None: ...
    def setFormatByArgumentIndex(self, int: int, format: Format) -> None: ...
    def setFormats(self, formatArray: typing.List[Format]) -> None: ...
    def setFormatsByArgumentIndex(self, formatArray: typing.List[Format]) -> None: ...
    def setLocale(self, locale: java.util.Locale) -> None: ...
    def toPattern(self) -> str: ...
    class Field(Format.Field):
        ARGUMENT: typing.ClassVar['MessageFormat.Field'] = ...

class NumberFormat(Format):
    INTEGER_FIELD: typing.ClassVar[int] = ...
    FRACTION_FIELD: typing.ClassVar[int] = ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def format(self, double: float, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, long: int, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, object: typing.Any) -> str: ...
    @typing.overload
    def format(self, double: float) -> str: ...
    @typing.overload
    def format(self, long: int) -> str: ...
    @typing.overload
    def format(self, object: typing.Any, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @staticmethod
    def getAvailableLocales() -> typing.List[java.util.Locale]: ...
    def getCurrency(self) -> java.util.Currency: ...
    @typing.overload
    @staticmethod
    def getCurrencyInstance() -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getCurrencyInstance(locale: java.util.Locale) -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getInstance() -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getInstance(locale: java.util.Locale) -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getIntegerInstance() -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getIntegerInstance(locale: java.util.Locale) -> 'NumberFormat': ...
    def getMaximumFractionDigits(self) -> int: ...
    def getMaximumIntegerDigits(self) -> int: ...
    def getMinimumFractionDigits(self) -> int: ...
    def getMinimumIntegerDigits(self) -> int: ...
    @typing.overload
    @staticmethod
    def getNumberInstance() -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getNumberInstance(locale: java.util.Locale) -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getPercentInstance() -> 'NumberFormat': ...
    @typing.overload
    @staticmethod
    def getPercentInstance(locale: java.util.Locale) -> 'NumberFormat': ...
    def getRoundingMode(self) -> java.math.RoundingMode: ...
    def hashCode(self) -> int: ...
    def isGroupingUsed(self) -> bool: ...
    def isParseIntegerOnly(self) -> bool: ...
    @typing.overload
    def parse(self, string: str, parsePosition: ParsePosition) -> java.lang.Number: ...
    @typing.overload
    def parse(self, string: str) -> java.lang.Number: ...
    @typing.overload
    def parseObject(self, string: str, parsePosition: ParsePosition) -> typing.Any: ...
    @typing.overload
    def parseObject(self, string: str) -> typing.Any: ...
    def setCurrency(self, currency: java.util.Currency) -> None: ...
    def setGroupingUsed(self, boolean: bool) -> None: ...
    def setMaximumFractionDigits(self, int: int) -> None: ...
    def setMaximumIntegerDigits(self, int: int) -> None: ...
    def setMinimumFractionDigits(self, int: int) -> None: ...
    def setMinimumIntegerDigits(self, int: int) -> None: ...
    def setParseIntegerOnly(self, boolean: bool) -> None: ...
    def setRoundingMode(self, roundingMode: java.math.RoundingMode) -> None: ...
    class Field(Format.Field):
        INTEGER: typing.ClassVar['NumberFormat.Field'] = ...
        FRACTION: typing.ClassVar['NumberFormat.Field'] = ...
        EXPONENT: typing.ClassVar['NumberFormat.Field'] = ...
        DECIMAL_SEPARATOR: typing.ClassVar['NumberFormat.Field'] = ...
        SIGN: typing.ClassVar['NumberFormat.Field'] = ...
        GROUPING_SEPARATOR: typing.ClassVar['NumberFormat.Field'] = ...
        EXPONENT_SYMBOL: typing.ClassVar['NumberFormat.Field'] = ...
        PERCENT: typing.ClassVar['NumberFormat.Field'] = ...
        PERMILLE: typing.ClassVar['NumberFormat.Field'] = ...
        CURRENCY: typing.ClassVar['NumberFormat.Field'] = ...
        EXPONENT_SIGN: typing.ClassVar['NumberFormat.Field'] = ...

class ChoiceFormat(NumberFormat):
    @typing.overload
    def __init__(self, doubleArray: typing.List[float], stringArray: typing.List[str]): ...
    @typing.overload
    def __init__(self, string: str): ...
    def applyPattern(self, string: str) -> None: ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def format(self, object: typing.Any) -> str: ...
    @typing.overload
    def format(self, double: float) -> str: ...
    @typing.overload
    def format(self, long: int) -> str: ...
    @typing.overload
    def format(self, double: float, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, long: int, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, object: typing.Any, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    def getFormats(self) -> typing.List[typing.Any]: ...
    def getLimits(self) -> typing.List[float]: ...
    def hashCode(self) -> int: ...
    @typing.overload
    @staticmethod
    def nextDouble(double: float, boolean: bool) -> float: ...
    @typing.overload
    @staticmethod
    def nextDouble(double: float) -> float: ...
    @typing.overload
    def parse(self, string: str, parsePosition: ParsePosition) -> java.lang.Number: ...
    @typing.overload
    def parse(self, string: str) -> java.lang.Number: ...
    @staticmethod
    def previousDouble(double: float) -> float: ...
    def setChoices(self, doubleArray: typing.List[float], stringArray: typing.List[str]) -> None: ...
    def toPattern(self) -> str: ...

class DecimalFormat(NumberFormat):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, decimalFormatSymbols: DecimalFormatSymbols): ...
    def applyLocalizedPattern(self, string: str) -> None: ...
    def applyPattern(self, string: str) -> None: ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def format(self, object: typing.Any) -> str: ...
    @typing.overload
    def format(self, double: float) -> str: ...
    @typing.overload
    def format(self, long: int) -> str: ...
    @typing.overload
    def format(self, object: typing.Any, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, double: float, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, long: int, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    def formatToCharacterIterator(self, object: typing.Any) -> AttributedCharacterIterator: ...
    def getCurrency(self) -> java.util.Currency: ...
    def getDecimalFormatSymbols(self) -> DecimalFormatSymbols: ...
    def getGroupingSize(self) -> int: ...
    def getMaximumFractionDigits(self) -> int: ...
    def getMaximumIntegerDigits(self) -> int: ...
    def getMinimumFractionDigits(self) -> int: ...
    def getMinimumIntegerDigits(self) -> int: ...
    def getMultiplier(self) -> int: ...
    def getNegativePrefix(self) -> str: ...
    def getNegativeSuffix(self) -> str: ...
    def getPositivePrefix(self) -> str: ...
    def getPositiveSuffix(self) -> str: ...
    def getRoundingMode(self) -> java.math.RoundingMode: ...
    def hashCode(self) -> int: ...
    def isDecimalSeparatorAlwaysShown(self) -> bool: ...
    def isParseBigDecimal(self) -> bool: ...
    @typing.overload
    def parse(self, string: str, parsePosition: ParsePosition) -> java.lang.Number: ...
    @typing.overload
    def parse(self, string: str) -> java.lang.Number: ...
    def setCurrency(self, currency: java.util.Currency) -> None: ...
    def setDecimalFormatSymbols(self, decimalFormatSymbols: DecimalFormatSymbols) -> None: ...
    def setDecimalSeparatorAlwaysShown(self, boolean: bool) -> None: ...
    def setGroupingSize(self, int: int) -> None: ...
    def setGroupingUsed(self, boolean: bool) -> None: ...
    def setMaximumFractionDigits(self, int: int) -> None: ...
    def setMaximumIntegerDigits(self, int: int) -> None: ...
    def setMinimumFractionDigits(self, int: int) -> None: ...
    def setMinimumIntegerDigits(self, int: int) -> None: ...
    def setMultiplier(self, int: int) -> None: ...
    def setNegativePrefix(self, string: str) -> None: ...
    def setNegativeSuffix(self, string: str) -> None: ...
    def setParseBigDecimal(self, boolean: bool) -> None: ...
    def setPositivePrefix(self, string: str) -> None: ...
    def setPositiveSuffix(self, string: str) -> None: ...
    def setRoundingMode(self, roundingMode: java.math.RoundingMode) -> None: ...
    def toLocalizedPattern(self) -> str: ...
    def toPattern(self) -> str: ...

class SimpleDateFormat(DateFormat):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, dateFormatSymbols: DateFormatSymbols): ...
    @typing.overload
    def __init__(self, string: str, locale: java.util.Locale): ...
    def applyLocalizedPattern(self, string: str) -> None: ...
    def applyPattern(self, string: str) -> None: ...
    def clone(self) -> typing.Any: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def format(self, date: java.util.Date) -> str: ...
    @typing.overload
    def format(self, object: typing.Any) -> str: ...
    @typing.overload
    def format(self, object: typing.Any, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, date: java.util.Date, stringBuffer: java.lang.StringBuffer, fieldPosition: FieldPosition) -> java.lang.StringBuffer: ...
    def formatToCharacterIterator(self, object: typing.Any) -> AttributedCharacterIterator: ...
    def get2DigitYearStart(self) -> java.util.Date: ...
    def getDateFormatSymbols(self) -> DateFormatSymbols: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def parse(self, string: str) -> java.util.Date: ...
    @typing.overload
    def parse(self, string: str, parsePosition: ParsePosition) -> java.util.Date: ...
    def set2DigitYearStart(self, date: java.util.Date) -> None: ...
    def setDateFormatSymbols(self, dateFormatSymbols: DateFormatSymbols) -> None: ...
    def toLocalizedPattern(self) -> str: ...
    def toPattern(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.text")``.

    Annotation: typing.Type[Annotation]
    AttributedCharacterIterator: typing.Type[AttributedCharacterIterator]
    AttributedString: typing.Type[AttributedString]
    Bidi: typing.Type[Bidi]
    BreakIterator: typing.Type[BreakIterator]
    CharacterIterator: typing.Type[CharacterIterator]
    ChoiceFormat: typing.Type[ChoiceFormat]
    CollationElementIterator: typing.Type[CollationElementIterator]
    CollationKey: typing.Type[CollationKey]
    Collator: typing.Type[Collator]
    DateFormat: typing.Type[DateFormat]
    DateFormatSymbols: typing.Type[DateFormatSymbols]
    DecimalFormat: typing.Type[DecimalFormat]
    DecimalFormatSymbols: typing.Type[DecimalFormatSymbols]
    FieldPosition: typing.Type[FieldPosition]
    Format: typing.Type[Format]
    MessageFormat: typing.Type[MessageFormat]
    Normalizer: typing.Type[Normalizer]
    NumberFormat: typing.Type[NumberFormat]
    ParseException: typing.Type[ParseException]
    ParsePosition: typing.Type[ParsePosition]
    RuleBasedCollator: typing.Type[RuleBasedCollator]
    SimpleDateFormat: typing.Type[SimpleDateFormat]
    StringCharacterIterator: typing.Type[StringCharacterIterator]
    spi: java.text.spi.__module_protocol__



import java.lang
import scala
import scala.collection
import scala.collection.immutable
import scala.runtime
import typing



class package:
    @staticmethod
    def byteswap32(v: int) -> int: ...
    @staticmethod
    def byteswap64(v: int) -> int: ...

_ByteswapHashing__Chained__T = typing.TypeVar('_ByteswapHashing__Chained__T')  # <T>
_ByteswapHashing__T = typing.TypeVar('_ByteswapHashing__T')  # <T>
class ByteswapHashing(scala.util.hashing.Hashing[_ByteswapHashing__T], typing.Generic[_ByteswapHashing__T]):
    def __init__(self): ...
    _chain__T = typing.TypeVar('_chain__T')  # <T>
    @staticmethod
    def chain(h: 'Hashing'[_chain__T]) -> 'Hashing'[_chain__T]: ...
    def hash(self, v: _ByteswapHashing__T) -> int: ...
    class Chained(scala.util.hashing.Hashing[_ByteswapHashing__Chained__T], typing.Generic[_ByteswapHashing__Chained__T]):
        def __init__(self, h: 'Hashing'[_ByteswapHashing__Chained__T]): ...
        def hash(self, v: _ByteswapHashing__Chained__T) -> int: ...

_Hashing__Default__T = typing.TypeVar('_Hashing__Default__T')  # <T>
_Hashing__T = typing.TypeVar('_Hashing__T')  # <T>
class Hashing(scala.Serializable, typing.Generic[_Hashing__T]):
    _default__T = typing.TypeVar('_default__T')  # <T>
    @staticmethod
    def default() -> 'Hashing.Default'[_default__T]: ...
    _fromFunction__T = typing.TypeVar('_fromFunction__T')  # <T>
    @staticmethod
    def fromFunction(f: scala.Function1[_fromFunction__T, typing.Any]) -> 'Hashing'[_fromFunction__T]: ...
    def hash(self, x: _Hashing__T) -> int: ...
    class Default(scala.util.hashing.Hashing[_Hashing__Default__T], typing.Generic[_Hashing__Default__T]):
        def __init__(self): ...
        def hash(self, x: _Hashing__Default__T) -> int: ...

_MurmurHash3__ArrayHashing__T = typing.TypeVar('_MurmurHash3__ArrayHashing__T')  # <T>
class MurmurHash3:
    def __init__(self): ...
    _arrayHash__T = typing.TypeVar('_arrayHash__T')  # <T>
    def arrayHash(self, a: typing.Any, seed: int) -> int: ...
    def arrayHash$mBc$sp(self, a: typing.List[int], seed: int) -> int: ...
    def arrayHash$mCc$sp(self, a: typing.List[str], seed: int) -> int: ...
    def arrayHash$mDc$sp(self, a: typing.List[float], seed: int) -> int: ...
    def arrayHash$mFc$sp(self, a: typing.List[float], seed: int) -> int: ...
    def arrayHash$mIc$sp(self, a: typing.List[int], seed: int) -> int: ...
    def arrayHash$mJc$sp(self, a: typing.List[int], seed: int) -> int: ...
    def arrayHash$mSc$sp(self, a: typing.List[int], seed: int) -> int: ...
    def arrayHash$mVc$sp(self, a: typing.List[scala.runtime.BoxedUnit], seed: int) -> int: ...
    def arrayHash$mZc$sp(self, a: typing.List[bool], seed: int) -> int: ...
    _arrayHashing__T = typing.TypeVar('_arrayHashing__T')  # <T>
    @staticmethod
    def arrayHashing() -> 'MurmurHash3.ArrayHashing'[_arrayHashing__T]: ...
    @staticmethod
    def arraySeed() -> int: ...
    def bytesHash(self, data: typing.List[int], seed: int) -> int: ...
    @staticmethod
    def bytesHashing() -> Hashing[typing.List[int]]: ...
    def finalizeHash(self, hash: int, length: int) -> int: ...
    def listHash(self, xs: scala.collection.immutable.List[typing.Any], seed: int) -> int: ...
    @staticmethod
    def mapHash(xs: scala.collection.Map[typing.Any, typing.Any]) -> int: ...
    @staticmethod
    def mapSeed() -> int: ...
    def mix(self, hash: int, data: int) -> int: ...
    def mixLast(self, hash: int, data: int) -> int: ...
    def orderedHash(self, xs: scala.collection.TraversableOnce[typing.Any], seed: int) -> int: ...
    @staticmethod
    def orderedHashing() -> Hashing[scala.collection.TraversableOnce[typing.Any]]: ...
    def productHash(self, x: scala.Product, seed: int) -> int: ...
    @staticmethod
    def productHashing() -> Hashing[scala.Product]: ...
    @staticmethod
    def productSeed() -> int: ...
    @staticmethod
    def seqHash(xs: scala.collection.Seq[typing.Any]) -> int: ...
    @staticmethod
    def seqSeed() -> int: ...
    @staticmethod
    def setHash(xs: scala.collection.Set[typing.Any]) -> int: ...
    @staticmethod
    def setSeed() -> int: ...
    def stringHash(self, str: typing.Union[java.lang.String, str], seed: int) -> int: ...
    @staticmethod
    def stringHashing() -> Hashing[java.lang.String]: ...
    @staticmethod
    def stringSeed() -> int: ...
    @staticmethod
    def symmetricSeed() -> int: ...
    @staticmethod
    def traversableSeed() -> int: ...
    def unorderedHash(self, xs: scala.collection.TraversableOnce[typing.Any], seed: int) -> int: ...
    @staticmethod
    def unorderedHashing() -> Hashing[scala.collection.TraversableOnce[typing.Any]]: ...
    class ArrayHashing(Hashing[typing.Any], typing.Generic[_MurmurHash3__ArrayHashing__T]):
        def __init__(self): ...
        def hash(self, a: typing.Any) -> int: ...
        def hash$mcB$sp(self, a: typing.List[int]) -> int: ...
        def hash$mcC$sp(self, a: typing.List[str]) -> int: ...
        def hash$mcD$sp(self, a: typing.List[float]) -> int: ...
        def hash$mcF$sp(self, a: typing.List[float]) -> int: ...
        def hash$mcI$sp(self, a: typing.List[int]) -> int: ...
        def hash$mcJ$sp(self, a: typing.List[int]) -> int: ...
        def hash$mcS$sp(self, a: typing.List[int]) -> int: ...
        def hash$mcV$sp(self, a: typing.List[scala.runtime.BoxedUnit]) -> int: ...
        def hash$mcZ$sp(self, a: typing.List[bool]) -> int: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.util.hashing")``.

    ByteswapHashing: typing.Type[ByteswapHashing]
    Hashing: typing.Type[Hashing]
    MurmurHash3: typing.Type[MurmurHash3]
    package: typing.Type[package]



import java.io
import java.lang
import java.nio
import java.security
import java.time
import java.util
import java.util.concurrent
import typing



class AclEntry:
    def equals(self, object: typing.Any) -> bool: ...
    def flags(self) -> java.util.Set['AclEntryFlag']: ...
    def hashCode(self) -> int: ...
    @typing.overload
    @staticmethod
    def newBuilder() -> 'AclEntry.Builder': ...
    @typing.overload
    @staticmethod
    def newBuilder(aclEntry: 'AclEntry') -> 'AclEntry.Builder': ...
    def permissions(self) -> java.util.Set['AclEntryPermission']: ...
    def principal(self) -> 'UserPrincipal': ...
    def toString(self) -> str: ...
    def type(self) -> 'AclEntryType': ...
    class Builder:
        def build(self) -> 'AclEntry': ...
        @typing.overload
        def setFlags(self, aclEntryFlagArray: typing.List['AclEntryFlag']) -> 'AclEntry.Builder': ...
        @typing.overload
        def setFlags(self, set: java.util.Set['AclEntryFlag']) -> 'AclEntry.Builder': ...
        @typing.overload
        def setPermissions(self, aclEntryPermissionArray: typing.List['AclEntryPermission']) -> 'AclEntry.Builder': ...
        @typing.overload
        def setPermissions(self, set: java.util.Set['AclEntryPermission']) -> 'AclEntry.Builder': ...
        def setPrincipal(self, userPrincipal: 'UserPrincipal') -> 'AclEntry.Builder': ...
        def setType(self, aclEntryType: 'AclEntryType') -> 'AclEntry.Builder': ...

class AclEntryFlag(java.lang.Enum['AclEntryFlag']):
    FILE_INHERIT: typing.ClassVar['AclEntryFlag'] = ...
    DIRECTORY_INHERIT: typing.ClassVar['AclEntryFlag'] = ...
    NO_PROPAGATE_INHERIT: typing.ClassVar['AclEntryFlag'] = ...
    INHERIT_ONLY: typing.ClassVar['AclEntryFlag'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'AclEntryFlag': ...
    @staticmethod
    def values() -> typing.List['AclEntryFlag']: ...

class AclEntryPermission(java.lang.Enum['AclEntryPermission']):
    READ_DATA: typing.ClassVar['AclEntryPermission'] = ...
    WRITE_DATA: typing.ClassVar['AclEntryPermission'] = ...
    APPEND_DATA: typing.ClassVar['AclEntryPermission'] = ...
    READ_NAMED_ATTRS: typing.ClassVar['AclEntryPermission'] = ...
    WRITE_NAMED_ATTRS: typing.ClassVar['AclEntryPermission'] = ...
    EXECUTE: typing.ClassVar['AclEntryPermission'] = ...
    DELETE_CHILD: typing.ClassVar['AclEntryPermission'] = ...
    READ_ATTRIBUTES: typing.ClassVar['AclEntryPermission'] = ...
    WRITE_ATTRIBUTES: typing.ClassVar['AclEntryPermission'] = ...
    DELETE: typing.ClassVar['AclEntryPermission'] = ...
    READ_ACL: typing.ClassVar['AclEntryPermission'] = ...
    WRITE_ACL: typing.ClassVar['AclEntryPermission'] = ...
    WRITE_OWNER: typing.ClassVar['AclEntryPermission'] = ...
    SYNCHRONIZE: typing.ClassVar['AclEntryPermission'] = ...
    LIST_DIRECTORY: typing.ClassVar['AclEntryPermission'] = ...
    ADD_FILE: typing.ClassVar['AclEntryPermission'] = ...
    ADD_SUBDIRECTORY: typing.ClassVar['AclEntryPermission'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'AclEntryPermission': ...
    @staticmethod
    def values() -> typing.List['AclEntryPermission']: ...

class AclEntryType(java.lang.Enum['AclEntryType']):
    ALLOW: typing.ClassVar['AclEntryType'] = ...
    DENY: typing.ClassVar['AclEntryType'] = ...
    AUDIT: typing.ClassVar['AclEntryType'] = ...
    ALARM: typing.ClassVar['AclEntryType'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'AclEntryType': ...
    @staticmethod
    def values() -> typing.List['AclEntryType']: ...

class AttributeView:
    def name(self) -> str: ...

class BasicFileAttributes:
    def creationTime(self) -> 'FileTime': ...
    def fileKey(self) -> typing.Any: ...
    def isDirectory(self) -> bool: ...
    def isOther(self) -> bool: ...
    def isRegularFile(self) -> bool: ...
    def isSymbolicLink(self) -> bool: ...
    def lastAccessTime(self) -> 'FileTime': ...
    def lastModifiedTime(self) -> 'FileTime': ...
    def size(self) -> int: ...

_FileAttribute__T = typing.TypeVar('_FileAttribute__T')  # <T>
class FileAttribute(typing.Generic[_FileAttribute__T]):
    def name(self) -> str: ...
    def value(self) -> _FileAttribute__T: ...

class FileTime(java.lang.Comparable['FileTime']):
    def compareTo(self, fileTime: 'FileTime') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    @staticmethod
    def fromMillis(long: int) -> 'FileTime': ...
    def hashCode(self) -> int: ...
    def to(self, timeUnit: java.util.concurrent.TimeUnit) -> int: ...
    def toInstant(self) -> java.time.Instant: ...
    def toMillis(self) -> int: ...
    def toString(self) -> str: ...

class PosixFilePermission(java.lang.Enum['PosixFilePermission']):
    OWNER_READ: typing.ClassVar['PosixFilePermission'] = ...
    OWNER_WRITE: typing.ClassVar['PosixFilePermission'] = ...
    OWNER_EXECUTE: typing.ClassVar['PosixFilePermission'] = ...
    GROUP_READ: typing.ClassVar['PosixFilePermission'] = ...
    GROUP_WRITE: typing.ClassVar['PosixFilePermission'] = ...
    GROUP_EXECUTE: typing.ClassVar['PosixFilePermission'] = ...
    OTHERS_READ: typing.ClassVar['PosixFilePermission'] = ...
    OTHERS_WRITE: typing.ClassVar['PosixFilePermission'] = ...
    OTHERS_EXECUTE: typing.ClassVar['PosixFilePermission'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'PosixFilePermission': ...
    @staticmethod
    def values() -> typing.List['PosixFilePermission']: ...

class PosixFilePermissions:
    @staticmethod
    def asFileAttribute(set: java.util.Set[PosixFilePermission]) -> FileAttribute[java.util.Set[PosixFilePermission]]: ...
    @staticmethod
    def fromString(string: str) -> java.util.Set[PosixFilePermission]: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def toString(set: java.util.Set[PosixFilePermission]) -> str: ...

class UserPrincipal(java.security.Principal):
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class UserPrincipalLookupService:
    def lookupPrincipalByGroupName(self, string: str) -> 'GroupPrincipal': ...
    def lookupPrincipalByName(self, string: str) -> UserPrincipal: ...

class UserPrincipalNotFoundException(java.io.IOException):
    def __init__(self, string: str): ...
    def getName(self) -> str: ...

class DosFileAttributes(BasicFileAttributes):
    def isArchive(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def isSystem(self) -> bool: ...

class FileAttributeView(AttributeView): ...

class FileStoreAttributeView(AttributeView): ...

class GroupPrincipal(UserPrincipal):
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class PosixFileAttributes(BasicFileAttributes):
    def group(self) -> GroupPrincipal: ...
    def owner(self) -> UserPrincipal: ...
    def permissions(self) -> java.util.Set[PosixFilePermission]: ...

class BasicFileAttributeView(FileAttributeView):
    def name(self) -> str: ...
    def readAttributes(self) -> BasicFileAttributes: ...
    def setTimes(self, fileTime: FileTime, fileTime2: FileTime, fileTime3: FileTime) -> None: ...

class FileOwnerAttributeView(FileAttributeView):
    def getOwner(self) -> UserPrincipal: ...
    def name(self) -> str: ...
    def setOwner(self, userPrincipal: UserPrincipal) -> None: ...

class UserDefinedFileAttributeView(FileAttributeView):
    def delete(self, string: str) -> None: ...
    def list(self) -> java.util.List[str]: ...
    def name(self) -> str: ...
    def read(self, string: str, byteBuffer: java.nio.ByteBuffer) -> int: ...
    def size(self, string: str) -> int: ...
    def write(self, string: str, byteBuffer: java.nio.ByteBuffer) -> int: ...

class AclFileAttributeView(FileOwnerAttributeView):
    def getAcl(self) -> java.util.List[AclEntry]: ...
    def name(self) -> str: ...
    def setAcl(self, list: java.util.List[AclEntry]) -> None: ...

class DosFileAttributeView(BasicFileAttributeView):
    def name(self) -> str: ...
    def readAttributes(self) -> DosFileAttributes: ...
    def setArchive(self, boolean: bool) -> None: ...
    def setHidden(self, boolean: bool) -> None: ...
    def setReadOnly(self, boolean: bool) -> None: ...
    def setSystem(self, boolean: bool) -> None: ...

class PosixFileAttributeView(BasicFileAttributeView, FileOwnerAttributeView):
    def name(self) -> str: ...
    def readAttributes(self) -> PosixFileAttributes: ...
    def setGroup(self, groupPrincipal: GroupPrincipal) -> None: ...
    def setPermissions(self, set: java.util.Set[PosixFilePermission]) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.nio.file.attribute")``.

    AclEntry: typing.Type[AclEntry]
    AclEntryFlag: typing.Type[AclEntryFlag]
    AclEntryPermission: typing.Type[AclEntryPermission]
    AclEntryType: typing.Type[AclEntryType]
    AclFileAttributeView: typing.Type[AclFileAttributeView]
    AttributeView: typing.Type[AttributeView]
    BasicFileAttributeView: typing.Type[BasicFileAttributeView]
    BasicFileAttributes: typing.Type[BasicFileAttributes]
    DosFileAttributeView: typing.Type[DosFileAttributeView]
    DosFileAttributes: typing.Type[DosFileAttributes]
    FileAttribute: typing.Type[FileAttribute]
    FileAttributeView: typing.Type[FileAttributeView]
    FileOwnerAttributeView: typing.Type[FileOwnerAttributeView]
    FileStoreAttributeView: typing.Type[FileStoreAttributeView]
    FileTime: typing.Type[FileTime]
    GroupPrincipal: typing.Type[GroupPrincipal]
    PosixFileAttributeView: typing.Type[PosixFileAttributeView]
    PosixFileAttributes: typing.Type[PosixFileAttributes]
    PosixFilePermission: typing.Type[PosixFilePermission]
    PosixFilePermissions: typing.Type[PosixFilePermissions]
    UserDefinedFileAttributeView: typing.Type[UserDefinedFileAttributeView]
    UserPrincipal: typing.Type[UserPrincipal]
    UserPrincipalLookupService: typing.Type[UserPrincipalLookupService]
    UserPrincipalNotFoundException: typing.Type[UserPrincipalNotFoundException]



import java.lang
import org.ergoplatform.wallet.interface4j
import scala
import scala.collection
import scala.util
import typing



class Mnemonic:
    def __init__(self, languageId: typing.Union[java.lang.String, str], strength: int): ...
    @staticmethod
    def AllowedEntropyLengths() -> scala.collection.Seq[typing.Any]: ...
    @staticmethod
    def AllowedStrengths() -> scala.collection.Seq[typing.Any]: ...
    @staticmethod
    def BitsGroupSize() -> int: ...
    @staticmethod
    def MnemonicSentenceSizes() -> scala.collection.Seq[typing.Any]: ...
    @staticmethod
    def Pbkdf2Algorithm() -> java.lang.String: ...
    @staticmethod
    def Pbkdf2Iterations() -> int: ...
    @staticmethod
    def Pbkdf2KeyLength() -> int: ...
    def generate(self) -> scala.util.Try[org.ergoplatform.wallet.interface4j.SecretString]: ...
    def toMnemonic(self, entropy: typing.List[int]) -> scala.util.Try[org.ergoplatform.wallet.interface4j.SecretString]: ...
    @staticmethod
    def toSeed(mnemonic: org.ergoplatform.wallet.interface4j.SecretString, passOpt: scala.Option[org.ergoplatform.wallet.interface4j.SecretString]) -> typing.List[int]: ...
    @staticmethod
    def toSeed$default$2() -> scala.Option[org.ergoplatform.wallet.interface4j.SecretString]: ...

class WordList(scala.Product, scala.Serializable):
    def __init__(self, words: scala.collection.Seq[typing.Union[java.lang.String, str]], delimiter: typing.Union[java.lang.String, str]): ...
    @staticmethod
    def AvailableLanguages() -> scala.collection.Seq[java.lang.String]: ...
    @staticmethod
    def apply(words: scala.collection.Seq[typing.Union[java.lang.String, str]], delimiter: typing.Union[java.lang.String, str]) -> 'WordList': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, words: scala.collection.Seq[typing.Union[java.lang.String, str]], delimiter: typing.Union[java.lang.String, str]) -> 'WordList': ...
    def copy$default$1(self) -> scala.collection.Seq[java.lang.String]: ...
    def copy$default$2(self) -> java.lang.String: ...
    def delimiter(self) -> java.lang.String: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def load(languageId: typing.Union[java.lang.String, str]) -> scala.util.Try['WordList']: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'WordList') -> scala.Option[scala.Tuple2[scala.collection.Seq[java.lang.String], java.lang.String]]: ...
    def words(self) -> scala.collection.Seq[java.lang.String]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.mnemonic")``.

    Mnemonic: typing.Type[Mnemonic]
    WordList: typing.Type[WordList]



import java.lang
import okhttp3
import typing



class ApiKeyAuth(okhttp3.Interceptor):
    def __init__(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]): ...
    def getApiKey(self) -> java.lang.String: ...
    def getLocation(self) -> java.lang.String: ...
    def getParamName(self) -> java.lang.String: ...
    def intercept(self, chain: okhttp3.Interceptor.Chain) -> okhttp3.Response: ...
    def setApiKey(self, string: typing.Union[java.lang.String, str]) -> None: ...

class HttpBasicAuth(okhttp3.Interceptor):
    def __init__(self): ...
    def getPassword(self) -> java.lang.String: ...
    def getUsername(self) -> java.lang.String: ...
    def intercept(self, chain: okhttp3.Interceptor.Chain) -> okhttp3.Response: ...
    def setCredentials(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> None: ...
    def setPassword(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setUsername(self, string: typing.Union[java.lang.String, str]) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.restapi.client.auth")``.

    ApiKeyAuth: typing.Type[ApiKeyAuth]
    HttpBasicAuth: typing.Type[HttpBasicAuth]



from typing import Dict, List
from ergo_python_appkit.appkit import ErgoAppKit
from org.ergoplatform.appkit import ErgoContract, ErgoValue, InputBox
from sigmastate.Values import ErgoTree

class ErgoContractBase:
    def __init__(self, appKit: ErgoAppKit, script: str = None, mapping: Dict[str,ErgoValue] = {}, ergoTree: ErgoTree = None) -> None:
        self.appKit = appKit
        if script is not None:
            with open(script) as f:
                self._ergoScript = f.read()
            self._ergoTree = self._appKit.compileErgoScript(self._ergoScript, mapping)
        if ergoTree is not None:
            self._ergoTree = ergoTree
        self.contract = self._appKit.contractFromTree(self._ergoTree)

    def validateInputBox(self, inBox: InputBox) -> bool:
        return inBox.getErgoTree() == self._ergoTree

    @property
    def contract(self) -> ErgoContract:
        return self._contract
    @contract.setter
    def contract(self, contract: ErgoContract) -> None:
        self._contract = contract

    @property
    def appKit(self) -> ErgoAppKit:
        return self._appKit
    @appKit.setter
    def appKit(self, appKit: ErgoAppKit) -> None:
        self._appKit = appKit




from pathlib import Path
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

def glob_fix(package_name, glob):
    # this assumes setup.py lives in the folder that contains the package
    package_path = Path(f'./{package_name}').resolve()
    return [str(path.relative_to(package_path)) 
            for path in package_path.glob(glob)]

setuptools.setup(
    name='ergo_python_appkit',  
    version='0.3.2',
    packages=['ergo_python_appkit'] ,
    author="Robert Pieter van Leeuwen",
    author_email="luivatra@gmail.com",
    description="A python wrapper for the Ergo Appkit",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ergo-pad/ergo-python-appkit",
    package_data={'ergo_python_appkit': [*glob_fix('ergo_python_appkit', 'typings/**/*'),'jars/*.jar']},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'jpype1',
    ]
 )


import org.ergoplatform
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org")``.

    ergoplatform: org.ergoplatform.__module_protocol__



from jpype.protocol import _JBigDecimal
import decimal
import java.io
import java.lang
import java.util
import typing



class BigDecimal(java.lang.Number, java.lang.Comparable['BigDecimal'], _JBigDecimal):
    ZERO: typing.ClassVar['BigDecimal'] = ...
    ONE: typing.ClassVar['BigDecimal'] = ...
    TEN: typing.ClassVar['BigDecimal'] = ...
    ROUND_UP: typing.ClassVar[int] = ...
    ROUND_DOWN: typing.ClassVar[int] = ...
    ROUND_CEILING: typing.ClassVar[int] = ...
    ROUND_FLOOR: typing.ClassVar[int] = ...
    ROUND_HALF_UP: typing.ClassVar[int] = ...
    ROUND_HALF_DOWN: typing.ClassVar[int] = ...
    ROUND_HALF_EVEN: typing.ClassVar[int] = ...
    ROUND_UNNECESSARY: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, charArray: typing.List[str]): ...
    @typing.overload
    def __init__(self, charArray: typing.List[str], int: int, int2: int): ...
    @typing.overload
    def __init__(self, charArray: typing.List[str], int: int, int2: int, mathContext: 'MathContext'): ...
    @typing.overload
    def __init__(self, charArray: typing.List[str], mathContext: 'MathContext'): ...
    @typing.overload
    def __init__(self, double: float): ...
    @typing.overload
    def __init__(self, double: float, mathContext: 'MathContext'): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, mathContext: 'MathContext'): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, mathContext: 'MathContext'): ...
    @typing.overload
    def __init__(self, bigInteger: 'BigInteger'): ...
    @typing.overload
    def __init__(self, bigInteger: 'BigInteger', int: int): ...
    @typing.overload
    def __init__(self, bigInteger: 'BigInteger', int: int, mathContext: 'MathContext'): ...
    @typing.overload
    def __init__(self, bigInteger: 'BigInteger', mathContext: 'MathContext'): ...
    @typing.overload
    def __init__(self, long: int): ...
    @typing.overload
    def __init__(self, long: int, mathContext: 'MathContext'): ...
    @typing.overload
    def abs(self) -> 'BigDecimal': ...
    @typing.overload
    def abs(self, mathContext: 'MathContext') -> 'BigDecimal': ...
    @typing.overload
    def add(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    @typing.overload
    def add(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], mathContext: 'MathContext') -> 'BigDecimal': ...
    def byteValueExact(self) -> int: ...
    def compareTo(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> int: ...
    @typing.overload
    def divide(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    @typing.overload
    def divide(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], int: int) -> 'BigDecimal': ...
    @typing.overload
    def divide(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], int: int, int2: int) -> 'BigDecimal': ...
    @typing.overload
    def divide(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], int: int, roundingMode: 'RoundingMode') -> 'BigDecimal': ...
    @typing.overload
    def divide(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], mathContext: 'MathContext') -> 'BigDecimal': ...
    @typing.overload
    def divide(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], roundingMode: 'RoundingMode') -> 'BigDecimal': ...
    @typing.overload
    def divideAndRemainder(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> typing.List['BigDecimal']: ...
    @typing.overload
    def divideAndRemainder(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], mathContext: 'MathContext') -> typing.List['BigDecimal']: ...
    @typing.overload
    def divideToIntegralValue(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    @typing.overload
    def divideToIntegralValue(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], mathContext: 'MathContext') -> 'BigDecimal': ...
    def doubleValue(self) -> float: ...
    def equals(self, object: typing.Any) -> bool: ...
    def floatValue(self) -> float: ...
    def hashCode(self) -> int: ...
    def intValue(self) -> int: ...
    def intValueExact(self) -> int: ...
    def longValue(self) -> int: ...
    def longValueExact(self) -> int: ...
    def max(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    def min(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    def movePointLeft(self, int: int) -> 'BigDecimal': ...
    def movePointRight(self, int: int) -> 'BigDecimal': ...
    @typing.overload
    def multiply(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    @typing.overload
    def multiply(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], mathContext: 'MathContext') -> 'BigDecimal': ...
    @typing.overload
    def negate(self) -> 'BigDecimal': ...
    @typing.overload
    def negate(self, mathContext: 'MathContext') -> 'BigDecimal': ...
    @typing.overload
    def plus(self) -> 'BigDecimal': ...
    @typing.overload
    def plus(self, mathContext: 'MathContext') -> 'BigDecimal': ...
    @typing.overload
    def pow(self, int: int) -> 'BigDecimal': ...
    @typing.overload
    def pow(self, int: int, mathContext: 'MathContext') -> 'BigDecimal': ...
    def precision(self) -> int: ...
    @typing.overload
    def remainder(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    @typing.overload
    def remainder(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], mathContext: 'MathContext') -> 'BigDecimal': ...
    def round(self, mathContext: 'MathContext') -> 'BigDecimal': ...
    def scale(self) -> int: ...
    def scaleByPowerOfTen(self, int: int) -> 'BigDecimal': ...
    @typing.overload
    def setScale(self, int: int) -> 'BigDecimal': ...
    @typing.overload
    def setScale(self, int: int, int2: int) -> 'BigDecimal': ...
    @typing.overload
    def setScale(self, int: int, roundingMode: 'RoundingMode') -> 'BigDecimal': ...
    def shortValueExact(self) -> int: ...
    def signum(self) -> int: ...
    def sqrt(self, mathContext: 'MathContext') -> 'BigDecimal': ...
    def stripTrailingZeros(self) -> 'BigDecimal': ...
    @typing.overload
    def subtract(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal]) -> 'BigDecimal': ...
    @typing.overload
    def subtract(self, bigDecimal: typing.Union['BigDecimal', decimal.Decimal], mathContext: 'MathContext') -> 'BigDecimal': ...
    def toBigInteger(self) -> 'BigInteger': ...
    def toBigIntegerExact(self) -> 'BigInteger': ...
    def toEngineeringString(self) -> str: ...
    def toPlainString(self) -> str: ...
    def toString(self) -> str: ...
    def ulp(self) -> 'BigDecimal': ...
    def unscaledValue(self) -> 'BigInteger': ...
    @typing.overload
    @staticmethod
    def valueOf(double: float) -> 'BigDecimal': ...
    @typing.overload
    @staticmethod
    def valueOf(long: int) -> 'BigDecimal': ...
    @typing.overload
    @staticmethod
    def valueOf(long: int, int: int) -> 'BigDecimal': ...

class BigInteger(java.lang.Number, java.lang.Comparable['BigInteger']):
    ZERO: typing.ClassVar['BigInteger'] = ...
    ONE: typing.ClassVar['BigInteger'] = ...
    TWO: typing.ClassVar['BigInteger'] = ...
    TEN: typing.ClassVar['BigInteger'] = ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int, int2: int): ...
    @typing.overload
    def __init__(self, int: int, byteArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, byteArray: typing.List[int], int2: int, int3: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, random: java.util.Random): ...
    @typing.overload
    def __init__(self, int: int, random: java.util.Random): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, int: int): ...
    def abs(self) -> 'BigInteger': ...
    def add(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def andNot(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def bitCount(self) -> int: ...
    def bitLength(self) -> int: ...
    def byteValueExact(self) -> int: ...
    def clearBit(self, int: int) -> 'BigInteger': ...
    def compareTo(self, bigInteger: 'BigInteger') -> int: ...
    def divide(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def divideAndRemainder(self, bigInteger: 'BigInteger') -> typing.List['BigInteger']: ...
    def doubleValue(self) -> float: ...
    def equals(self, object: typing.Any) -> bool: ...
    def flipBit(self, int: int) -> 'BigInteger': ...
    def floatValue(self) -> float: ...
    def gcd(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def getLowestSetBit(self) -> int: ...
    def hashCode(self) -> int: ...
    def intValue(self) -> int: ...
    def intValueExact(self) -> int: ...
    def isProbablePrime(self, int: int) -> bool: ...
    def longValue(self) -> int: ...
    def longValueExact(self) -> int: ...
    def max(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def min(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def mod(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def modInverse(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def modPow(self, bigInteger: 'BigInteger', bigInteger2: 'BigInteger') -> 'BigInteger': ...
    def multiply(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def negate(self) -> 'BigInteger': ...
    def nextProbablePrime(self) -> 'BigInteger': ...
    def pow(self, int: int) -> 'BigInteger': ...
    @staticmethod
    def probablePrime(int: int, random: java.util.Random) -> 'BigInteger': ...
    def remainder(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def setBit(self, int: int) -> 'BigInteger': ...
    def shiftLeft(self, int: int) -> 'BigInteger': ...
    def shiftRight(self, int: int) -> 'BigInteger': ...
    def shortValueExact(self) -> int: ...
    def signum(self) -> int: ...
    def sqrt(self) -> 'BigInteger': ...
    def sqrtAndRemainder(self) -> typing.List['BigInteger']: ...
    def subtract(self, bigInteger: 'BigInteger') -> 'BigInteger': ...
    def testBit(self, int: int) -> bool: ...
    def toByteArray(self) -> typing.List[int]: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self, int: int) -> str: ...
    @staticmethod
    def valueOf(long: int) -> 'BigInteger': ...
    def xor(self, bigInteger: 'BigInteger') -> 'BigInteger': ...

class MathContext(java.io.Serializable):
    UNLIMITED: typing.ClassVar['MathContext'] = ...
    DECIMAL32: typing.ClassVar['MathContext'] = ...
    DECIMAL64: typing.ClassVar['MathContext'] = ...
    DECIMAL128: typing.ClassVar['MathContext'] = ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, roundingMode: 'RoundingMode'): ...
    @typing.overload
    def __init__(self, string: str): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getPrecision(self) -> int: ...
    def getRoundingMode(self) -> 'RoundingMode': ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class RoundingMode(java.lang.Enum['RoundingMode']):
    UP: typing.ClassVar['RoundingMode'] = ...
    DOWN: typing.ClassVar['RoundingMode'] = ...
    CEILING: typing.ClassVar['RoundingMode'] = ...
    FLOOR: typing.ClassVar['RoundingMode'] = ...
    HALF_UP: typing.ClassVar['RoundingMode'] = ...
    HALF_DOWN: typing.ClassVar['RoundingMode'] = ...
    HALF_EVEN: typing.ClassVar['RoundingMode'] = ...
    UNNECESSARY: typing.ClassVar['RoundingMode'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(int: int) -> 'RoundingMode': ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'RoundingMode': ...
    @staticmethod
    def values() -> typing.List['RoundingMode']: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.math")``.

    BigDecimal: typing.Type[BigDecimal]
    BigInteger: typing.Type[BigInteger]
    MathContext: typing.Type[MathContext]
    RoundingMode: typing.Type[RoundingMode]



import java.net
import java.nio.channels
import java.util.concurrent
import typing



class AbstractInterruptibleChannel(java.nio.channels.Channel, java.nio.channels.InterruptibleChannel):
    def close(self) -> None: ...
    def isOpen(self) -> bool: ...

class AbstractSelectableChannel(java.nio.channels.SelectableChannel):
    def blockingLock(self) -> typing.Any: ...
    def configureBlocking(self, boolean: bool) -> java.nio.channels.SelectableChannel: ...
    def isBlocking(self) -> bool: ...
    def isRegistered(self) -> bool: ...
    def keyFor(self, selector: java.nio.channels.Selector) -> java.nio.channels.SelectionKey: ...
    def provider(self) -> 'SelectorProvider': ...
    @typing.overload
    def register(self, selector: java.nio.channels.Selector, int: int) -> java.nio.channels.SelectionKey: ...
    @typing.overload
    def register(self, selector: java.nio.channels.Selector, int: int, object: typing.Any) -> java.nio.channels.SelectionKey: ...

class AbstractSelectionKey(java.nio.channels.SelectionKey):
    def cancel(self) -> None: ...
    def isValid(self) -> bool: ...

class AbstractSelector(java.nio.channels.Selector):
    def close(self) -> None: ...
    def isOpen(self) -> bool: ...
    def provider(self) -> 'SelectorProvider': ...

class AsynchronousChannelProvider:
    @typing.overload
    def openAsynchronousChannelGroup(self, int: int, threadFactory: java.util.concurrent.ThreadFactory) -> java.nio.channels.AsynchronousChannelGroup: ...
    @typing.overload
    def openAsynchronousChannelGroup(self, executorService: java.util.concurrent.ExecutorService, int: int) -> java.nio.channels.AsynchronousChannelGroup: ...
    def openAsynchronousServerSocketChannel(self, asynchronousChannelGroup: java.nio.channels.AsynchronousChannelGroup) -> java.nio.channels.AsynchronousServerSocketChannel: ...
    def openAsynchronousSocketChannel(self, asynchronousChannelGroup: java.nio.channels.AsynchronousChannelGroup) -> java.nio.channels.AsynchronousSocketChannel: ...
    @staticmethod
    def provider() -> 'AsynchronousChannelProvider': ...

class SelectorProvider:
    def inheritedChannel(self) -> java.nio.channels.Channel: ...
    @typing.overload
    def openDatagramChannel(self) -> java.nio.channels.DatagramChannel: ...
    @typing.overload
    def openDatagramChannel(self, protocolFamily: java.net.ProtocolFamily) -> java.nio.channels.DatagramChannel: ...
    def openPipe(self) -> java.nio.channels.Pipe: ...
    def openSelector(self) -> AbstractSelector: ...
    def openServerSocketChannel(self) -> java.nio.channels.ServerSocketChannel: ...
    def openSocketChannel(self) -> java.nio.channels.SocketChannel: ...
    @staticmethod
    def provider() -> 'SelectorProvider': ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.nio.channels.spi")``.

    AbstractInterruptibleChannel: typing.Type[AbstractInterruptibleChannel]
    AbstractSelectableChannel: typing.Type[AbstractSelectableChannel]
    AbstractSelectionKey: typing.Type[AbstractSelectionKey]
    AbstractSelector: typing.Type[AbstractSelector]
    AsynchronousChannelProvider: typing.Type[AsynchronousChannelProvider]
    SelectorProvider: typing.Type[SelectorProvider]
